Module env

Module env 

Environment-variable capability trait and error types.

Sync: env access is a single map lookup on both native (std::env) and wasm (process.env).

set and unset are intentionally absent from this trait. libdatadog is embedded in many kinds of runtime, where mutating the process environment very much unsafe. Exposing mutation here would make it trivially easy for callers to corrupt the environment of a multi-threaded host process.

Enums

EnvError

Traits

EnvCapability