Module http

Module http 

HTTP capability trait and error types.

Request and response types are provided by the http crate, which is a pure-types crate with no platform dependencies (compiles on wasm). The body type is bytes::Bytes.

Structs

BufferingBodySender
Fallback StreamingBodySender that buffers every chunk in memory and only issues the request once the sender side is dropped.

Enums

HttpError

Traits

HttpClientCapability
StreamingBodySender
A handle for feeding a HttpClientCapability::request_streamed request body incrementally, one chunk at a time.

Type Aliases

BodySender
ChunkFuture
ResponseFuture