MaybeSend

Trait MaybeSend 

pub trait MaybeSend: Send { }
A trait that is Send on native targets, but auto-implemented on wasm.

Use this instead of Send in all capability trait bounds.

Implementors

Source

impl<T: Send> MaybeSend for T

Available on non-WebAssembly only.