HTTP capability trait and error types.
Request and response types are provided by the http crate, which is a
pure-types crate with no platform dependencies (compiles on wasm). The body
type is bytes::Bytes.
Structs
- Buffering
Body Sender - Fallback
StreamingBodySenderthat buffers every chunk in memory and only issues the request once the sender side is dropped.
Enums
Traits
- Http
Client Capability - Streaming
Body Sender - A handle for feeding a
HttpClientCapability::request_streamedrequest body incrementally, one chunk at a time.