HTTP capability trait and error types.
Request and response types are provided by the http crate, which is a
pure-types crate with no platform dependencies (compiles on wasm). The body
type is bytes::Bytes.
HTTP capability trait and error types.
Request and response types are provided by the http crate, which is a
pure-types crate with no platform dependencies (compiles on wasm). The body
type is bytes::Bytes.